@@ -24,6 +24,7 @@ class DefaultUrlHandler(HttpPageHandler):
         check multiple source of data.
         """
         if not url:
+            WebLogger.error("Default Url Handler - no url")
             return
 
         if self.request:
@@ -32,6 +33,7 @@ class DefaultUrlHandler(HttpPageHandler):
             request = PageRequestObject(url)
 
         request.url = url
+        request.handler_name = "HttpPageHandler"
         request.handler_type = HttpPageHandler
         request.crawler_type = None
         if crawler_name:
@@ -43,6 +45,8 @@ class DefaultUrlHandler(HttpPageHandler):
             )
             return url
 
+        WebLogger.error("Default Url Handler - no builder")
+
     def build_default_url(self, url, crawler_name=None):
         """
         TODO reneme get_page_url to build_http_url
@@ -67,6 +71,9 @@ class DefaultUrlHandler(HttpPageHandler):
             )
             return url
 
+    def get_code(self):
+        return self.code
+
 
 class DefaultChannelHandler(DefaultUrlHandler):
     """
@@ -95,7 +102,12 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
             if feed:
                 sources.append(feed)
 
-        sources.append(self.get_channel_url())
+        channel_url = self.get_channel_url()
+        if channel_url:
+            sources.append(channel_url)
+
+        if len(sources) == 0:
+            sources.append(self.url)
 
         return sources
 
@@ -104,9 +116,6 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
         We obtain information about channel.
         We cannot use HTML page to obtain thumbnail - as web page asks to log in to view this
         """
-        if self.dead:
-            return
-
         if self.contents:
             return self.contents
 
@@ -114,15 +123,9 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
             return self.get_response().get_text()
 
     def get_response(self):
-        if not self.code:
-            return
-
         if self.response:
             return self.response
 
-        if self.dead:
-            return
-
         handles = []
         with ThreadPoolExecutor() as executor:
             for channel_source in self.get_channel_sources():
@@ -142,7 +145,7 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
 
     def get_streams(self):
         for page_url in self.channel_sources_urls.values():
-            self.streams[page_url] = page_url.get_response()
+            self.streams[page_url.url] = page_url.get_response()
 
         return self.streams
 
@@ -159,8 +162,9 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
     def get_entries(self):
         for url in self.channel_sources_urls.values():
             entries = url.get_entries()
-            if entries and len(entries) > 0:
+            if entries and len(list(entries)) > 0:
                 return entries
+        return []
 
     def get_title(self):
         for url in self.channel_sources_urls.values():
@@ -182,10 +186,7 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
 
     def get_thumbnail(self):
         for url in self.channel_sources_urls.values():
-            print(url.url)
             thumbnail = url.get_thumbnail()
-            print(url.get_response())
-            print(thumbnail)
             if thumbnail:
                 return thumbnail
 
@@ -206,3 +207,9 @@ class DefaultCompoundChannelHandler(DefaultChannelHandler):
             tags = url.get_tags()
             if tags:
                 return tags
+
+    def get_date_published(self):
+        for url in self.channel_sources_urls.values():
+            date_published = url.get_date_published()
+            if date_published:
+                return date_published
