@@ -1,5 +1,6 @@
 from .contentinterface import ContentInterface
 from .remoteserver import RemoteServer
+from .webtools import json_decode_field
 
 
 class RemoteUrl(ContentInterface):
@@ -23,7 +24,7 @@ class RemoteUrl(ContentInterface):
 
     def get_responses(self):
         if self.all_properties is None:
-            self.all_properties = self.server.get_getj(self.url)
+            self.all_properties = self.server.get_getj(url=self.url)
 
         if not self.responses:
             self.responses = {"Default": RemoteServer.get_response(self.all_properties)}
@@ -132,10 +133,17 @@ class RemoteUrl(ContentInterface):
         return self.server.get_linkj(self.url)
 
     def get_hash(self):
-        return self.get_response().hash
+        return self.get_response().get_hash()
 
-    def get_hash_body(self):
-        return self.get_response().body_hash
+    def get_body_hash(self):
+        return self.get_response().get_body_hash()
+
+    def get_meta_hash(self):
+        hash_section = RemoteServer.read_properties_section(
+            "PropertiesHash", self.all_properties
+        )
+        if hash_section:
+            return json_decode_field(hash_section)
 
     def get_social_properties(self):
         if self.social_properties is None:
