@@ -12,6 +12,7 @@ import traceback
 from webtoolkit.utils.dateutils import DateUtils
 
 from webtoolkit import (
+    calculate_hash,
     json_encode_field,
     json_decode_field,
     PageResponseObject,
@@ -32,6 +33,7 @@ from webtoolkit.tests.fakeinternetcontents import (
     webpage_with_rss_link_rss_contents,
     webpage_html_casinos,
     webpage_html_canonical_1,
+    webpage_with_date_published,
 )
 from webtoolkit.tests.fake.geekwirecom import (
     geekwire_feed,
@@ -283,12 +285,19 @@ class TestResponseObject(PageResponseObject):
     def get_text_for_url(self, url):
         if url.startswith("https://www.youtube.com/channel/"):
             return self.get_contents_youtube_channel(url)
+
         if url.startswith("https://youtube.com/channel/"):
             return self.get_contents_youtube_channel(url)
 
+        if url.startswith("https://www.youtube.com/watch?v=666"):
+            self.status_code = 500
+
         if url.startswith("https://www.youtube.com/watch?v=666"):
             return webpage_no_pubdate_rss
 
+        if url.startswith("https://www.youtube.com/watch?v=date_published"):
+            return webpage_with_date_published
+
         if url.startswith(
             "https://www.youtube.com/feeds/videos.xml?channel_id=UCXuqSBlHAE6Xw-yeJA0Tunw"
         ):
@@ -306,6 +315,18 @@ class TestResponseObject(PageResponseObject):
         if url == "https://www.youtube.com/product/sitemap.xml":
             return youtube_sitemap_product
 
+        if url.startswith("https://returnyoutubedislikeapi.com/votes?videoId=666"):
+            return ""
+
+        if url.startswith("https://returnyoutubedislikeapi.com/votes?videoId"):
+            return return_dislike_json
+
+        if url.startswith("https://odysee.com/$/rss"):
+            return webpage_samtime_youtube_rss
+
+        if url.startswith("https://odysee.com/"):
+            return youtube_channel_html_linus_tech_tips
+
         if url == "https://rss-page-with-broken-content-type.com/feed":
             return youtube_channel_html_linus_tech_tips
 
@@ -327,12 +348,6 @@ class TestResponseObject(PageResponseObject):
         if url.startswith("https://api.github.com"):
             return github_json
 
-        if url.startswith("https://returnyoutubedislikeapi.com/votes?videoId"):
-            return return_dislike_json
-
-        if url.startswith("https://odysee.com/$/rss"):
-            return webpage_samtime_youtube_rss
-
         if url.startswith("https://hnrss.org"):
             return webpage_hackernews_rss
 
@@ -545,9 +560,7 @@ class TestResponseObject(PageResponseObject):
             self.binary = text.encode("utf-8")
 
     def get_contents_youtube_channel(self, url):
-        print("s")
         if url.startswith("https://www.youtube.com/channel"):
-            print("o")
             return youtube_channel_html_linus_tech_tips
         elif url.startswith("https://youtube.com/channel"):
             return youtube_channel_html_linus_tech_tips
@@ -637,10 +650,15 @@ class TestResponseObject(PageResponseObject):
             return """{}"""
 
     def __str__(self):
-        return "TestResponseObject: Url:{} Status code:{} Headers:{}".format(
+        has_text_data = "Yes" if self.text else "No"
+        has_binary_data = "Yes" if self.binary else "No"
+
+        return "TestResponseObject: Url:{} Status code:{} Headers:{} Text:{} Binary:{}".format(
             self.url,
             self.status_code,
             self.headers,
+            has_text_data,
+            has_binary_data,
         )
 
 
@@ -676,10 +694,14 @@ class FakeInternetData(object):
     def get_all_properties(self):
         data = []
         data.append({"name": "Properties", "data": self.properties})
-        data.append({"name": "Settings", "data": None})
+        data.append({"name": "Request", "data": None})
         data.append({"name": "Response", "data": self.response})
         data.append({"name": "Headers", "data": {}})
         data.append({"name": "Entries", "data": self.entries})
+
+        properties_hash = json_encode_field(calculate_hash(str(self.properties)))
+        data.append({"name": "PropertiesHash", "data": properties_hash})
+
         data.append(
             {
                 "name": "Streams",
@@ -692,51 +714,54 @@ class FakeInternetData(object):
 
         return data
 
-    def get_getj(self, name="", settings=None):
-        if self.url == "https://linkedin.com":
+    def get_getj(self, request=None, url=None):
+        if request:
+            url = request.url
+
+        if url == "https://linkedin.com":
             self.properties["title"] = "Https LinkedIn Page title"
             self.properties["description"] = "Https LinkedIn Page description"
-        elif self.url == "https://m.youtube.com/watch?v=1234":
+        elif url == "https://m.youtube.com/watch?v=1234":
             self.properties["link"] = "https://www.youtube.com/watch?v=1234"
             self.properties["feeds"] = [
                 "https://www.youtube.com/feeds/videos.xml?channel_id=1234-channel-id",
             ]
             self.properties["title"] = "YouTube 1234 video"
             self.properties["language"] = None
-        elif self.url == "https://www.youtube.com/watch?v=1234":
+        elif url == "https://www.youtube.com/watch?v=1234":
             self.properties["link"] = "https://www.youtube.com/watch?v=1234"
             self.properties["feeds"] = [
                 "https://www.youtube.com/feeds/videos.xml?channel_id=1234-channel-id",
             ]
             self.properties["title"] = "YouTube 1234 video"
             self.properties["language"] = None
-        elif self.url == "https://youtu.be/1234":
+        elif url == "https://youtu.be/1234":
             self.properties["link"] = "https://www.youtube.com/watch?v=1234"
             self.properties["feeds"] = [
                 "https://www.youtube.com/feeds/videos.xml?channel_id=1234-channel-id",
             ]
             self.properties["title"] = "YouTube 1234 video"
             self.properties["language"] = None
-        elif self.url == "https://www.reddit.com/r/searchengines/":
+        elif url == "https://www.reddit.com/r/searchengines/":
             self.properties["feeds"] = ["https://www.reddit.com/r/searchengines/.rss"]
-        elif self.url == "https://www.reddit.com/r/searchengines":
+        elif url == "https://www.reddit.com/r/searchengines":
             self.properties["feeds"] = ["https://www.reddit.com/r/searchengines/.rss"]
-        elif self.url == "https://www.reddit.com/r/searchengines/.rss":
+        elif url == "https://www.reddit.com/r/searchengines/.rss":
             self.set_entries(10)
-        elif self.url == "https://page-with-rss-link.com":
+        elif url == "https://page-with-rss-link.com":
             self.properties["title"] = "Page with RSS link"
             self.properties["feeds"] = ["https://page-with-rss-link.com/feed"]
-        elif self.url == "https://page-with-rss-link.com/feed":
+        elif url == "https://page-with-rss-link.com/feed":
             self.set_entries(10)
             self.response["Content-Type"] = "application/rss+xml"
             self.properties["title"] = "Page with RSS link - RSS contents"
-        elif self.url == "https://www.codeproject.com/WebServices/NewsRSS.aspx":
+        elif url == "https://www.codeproject.com/WebServices/NewsRSS.aspx":
             self.set_entries(13)
             self.response["Content-Type"] = "application/rss+xml"
             self.properties["thumbnail"] = (
                 "https://www.codeproject.com/App_Themes/Std/Img/logo100x30.gif"
             )
-        elif self.url == "https://no-props-page.com":
+        elif url == "https://no-props-page.com":
             self.properties["title"] = None
             self.properties["description"] = None
             self.properties["date_published"] = None
@@ -745,92 +770,92 @@ class FakeInternetData(object):
             self.properties["album"] = None
             self.properties["page_rating"] = 0
             self.properties["thumbnail"] = None
-        elif self.url == "https://page-with-http-status-615.com":
+        elif url == "https://page-with-http-status-615.com":
             self.response["status_code"] = HTTP_STATUS_CODE_SERVER_TOO_MANY_REQUESTS
-        elif self.url == "https://page-with-http-status-614.com":
+        elif url == "https://page-with-http-status-614.com":
             self.response["status_code"] = HTTP_STATUS_CODE_SERVER_ERROR
-        elif self.url == "https://page-with-http-status-600.com":
+        elif url == "https://page-with-http-status-600.com":
             self.response["status_code"] = HTTP_STATUS_CODE_EXCEPTION
-        elif self.url == "https://page-with-http-status-500.com":
+        elif url == "https://page-with-http-status-500.com":
             self.response["status_code"] = 500
-        elif self.url == "https://page-with-http-status-429.com":
+        elif url == "https://page-with-http-status-429.com":
             self.response["status_code"] = HTTP_STATUS_TOO_MANY_REQUESTS
-        elif self.url == "https://page-with-http-status-403.com":
+        elif url == "https://page-with-http-status-403.com":
             self.response["status_code"] = HTTP_STATUS_USER_AGENT
-        elif self.url == "https://page-with-http-status-400.com":
+        elif url == "https://page-with-http-status-400.com":
             self.response["status_code"] = 400
-        elif self.url == "https://page-with-http-status-300.com":
+        elif url == "https://page-with-http-status-300.com":
             self.response["status_code"] = 300
-        elif self.url == "https://page-with-http-status-200.com":
+        elif url == "https://page-with-http-status-200.com":
             self.response["status_code"] = 200
-        elif self.url == "https://page-with-http-status-100.com":
+        elif url == "https://page-with-http-status-100.com":
             self.response["status_code"] = 100
-        elif self.url == "http://page-with-http-status-500.com":
+        elif url == "http://page-with-http-status-500.com":
             self.response["status_code"] = 500
-        elif self.url == "http://page-with-http-status-400.com":
+        elif url == "http://page-with-http-status-400.com":
             self.response["status_code"] = 400
-        elif self.url == "http://page-with-http-status-300.com":
+        elif url == "http://page-with-http-status-300.com":
             self.response["status_code"] = 300
-        elif self.url == "http://page-with-http-status-200.com":
+        elif url == "http://page-with-http-status-200.com":
             self.response["status_code"] = 200
-        elif self.url == "http://page-with-http-status-100.com":
+        elif url == "http://page-with-http-status-100.com":
             self.response["status_code"] = 100
-        elif self.url == "https://www.youtube.com/watch?v=666":
+        elif url == "https://www.youtube.com/watch?v=666":
             self.response["status_code"] = 500
-        elif self.url == "https://invalid.rsspage.com/rss.xml":
+        elif url == "https://invalid.rsspage.com/rss.xml":
             self.response["status_code"] = 500
         elif (
-            self.url
+            url
             == "https://www.youtube.com/feeds/videos.xml?channel_id=SAMTIMESAMTIMESAMTIMESAM"
         ):
             self.set_entries(13)
             self.response["Content-Type"] = "application/rss+xml"
-            self.properties["feeds"] = [self.url]
+            self.properties["feeds"] = [url]
         elif (
-            self.url
+            url
             == "https://www.youtube.com/feeds/videos.xml?channel_id=NOLANGUAGETIMESAMTIMESAM"
         ):
             self.set_entries(13, language=None)
             self.response["Content-Type"] = "application/rss+xml"
-            self.properties["feeds"] = [self.url]
+            self.properties["feeds"] = [url]
             self.properties["language"] = None
-        elif self.url.startswith("https://odysee.com/$/rss"):
+        elif url.startswith("https://odysee.com/$/rss"):
             self.set_entries(13)
             self.response["Content-Type"] = "application/rss+xml"
-            self.properties["feeds"] = [self.url]
-        elif self.url == "https://www.geekwire.com/feed":
+            self.properties["feeds"] = [url]
+        elif url == "https://www.geekwire.com/feed":
             self.text_data = geekwire_feed
             self.response["Content-Type"] = "application/rss+xml"
-            self.properties["feeds"] = [self.url]
+            self.properties["feeds"] = [url]
         elif (
-            self.url
+            url
             == "https://www.youtube.com/feeds/videos.xml?channel_id=1234-channel-id"
         ):
             self.set_entries(13)
             self.response["Content-Type"] = "application/rss+xml"
-            self.properties["feeds"] = [self.url]
-        elif self.url == "https://instance.com/apps/rsshistory/sources-json":
+            self.properties["feeds"] = [url]
+        elif url == "https://instance.com/apps/rsshistory/sources-json":
             self.properties["title"] = "Instance Proxy"
-        elif self.url == "https://v.firebog.net/hosts/AdguardDNS.txt":
+        elif url == "https://v.firebog.net/hosts/AdguardDNS.txt":
             self.text_data = firebog_adguard_list
-        elif self.url == "https://v.firebog.net/hosts/static/w3kbl.txt":
+        elif url == "https://v.firebog.net/hosts/static/w3kbl.txt":
             self.text_data = firebog_w3kbl_list
-        elif self.url == "https://v.firebog.net/hosts/lists.php?type=tick":
+        elif url == "https://v.firebog.net/hosts/lists.php?type=tick":
             self.text_data = firebog_tick_lists
-        elif self.url == "https://v.firebog.net/hosts/RPiList-Malware.txt":
+        elif url == "https://v.firebog.net/hosts/RPiList-Malware.txt":
             self.text_data = firebog_malware
-        elif self.url == "https://casino.com":
+        elif url == "https://casino.com":
             self.properties["title"] = "Casino Casino Casino"
             self.properties["description"] = "Casino Casino Casino"
-        elif self.url == "https://nfsw.com":
+        elif url == "https://nfsw.com":
             self.properties["title"] = "AI NSFW girlfriend"
             self.properties["description"] = "AI NSFW girlfriend"
-        elif self.url == "https://binary.com/file":
+        elif url == "https://binary.com/file":
             self.properties["title"] = ""
             self.properties["description"] = ""
             self.binary_data = "text".encode()
 
-        if self.url.find("reddit") >= 0:
+        if url.find("reddit") >= 0:
             self.properties["language"] = "en"
 
         if self.response["status_code"] > 200 and self.response["status_code"] < 400:
